import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 *
 * JetChart   supports   multiples   scales,  arranged    along the  left   or
 * right vertical axis. The GraphSet class is used to group series separately
 * and display them against multiple scales. Each GraphSet object is completely
 * independent, there is no interaction between multiple instances of GraphSet.
 *
 * See JetChart documentation for further details about the GraphSet class.
 *
 * This demo displays four series, each one displayed against a  different scale
 * The scales are automatically arranged from top to bottom, two of them   along
 * the left axis and the remaining along the right axis.  A  gap between scales
 * is manually set to prevent scales labels from overlapping.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com 
 */
public class Main extends JFrame  {

    Graph graph;

    GraphSet gs1,gs2,gs3;

    LineSerie ls;
    AreaSerie as;
    BarSerie bs;
    CandleStickSerie cs;

    public Main() {
	
	// Sets the frame title.
	setTitle("The JetChart Library - Multiple Scales Demo");
	
	// Series values.
	double[] values1={17,22,10,33,44,8,-50,-70,10,30};
	double[] values2={3543,2243,1890,2991,3654,2500,1600,1900,2200,3000};
	double[] values3={131.90,132.80,130.50,131.00,136.75,135.00,131.50,130.50,132.40,133.30};
	double[][] values4={{185.00,178.00,179.00,182.50},{196.00,183.50,183.95,192.90},
			  {196.95,189.20,194.00,190.00},{195.50,186.55,191.00,187.25},
			  {195.60,190.00,192.00,192.00},{207.35,190.10,191.10,207.35},
			  {214.00,193.10,211.25,196.15},{202.80,189.50,196.00,196.45},
			  {206.35,194.30,197.00,199.00},{208.00,197.00,204.00,198.10}};


	
	// Creates a bar series.
	bs=new BarSerie(values1,"Bar Series");
	bs.setColor(Color.green.darker());

	// Creates a line series.
	ls=new LineSerie(values2,"Line Series");
	ls.setColor(Color.magenta);
	ls.setThickness(2);

	// Creates an area series.
	as=new AreaSerie(values3,"Area Series");
	as.setColor(Color.red);
	
	// Creates a candlestick series.
	cs=new CandleStickSerie(values4);
	cs.setLegendEnabled(true);
	cs.setTitle("CandleStick\nSeries");
	cs.setColor(Color.blue);
	cs.setWidth(4);
	cs.setBullishColor(Color.green);
	cs.setBearishColor(Color.red);

	// Creates the chart context.
	createGraph();
	
	// Adds series to the chart context.
	graph.addSerie(ls);
	graph.addSerie(bs);
	graph.addSerie(as);
	graph.addSerie(cs);
	
	/**
	 * The default behaviour of JetChart is to calculate the start and end points
	 * of each Scale object by checking the values manually passed with the 
	 * Scale.setStartPoint(float startPoint) and Scale.setEndPoint(float endPoint)
	 * methods, thus the user is in charge of setting scale positioning.
	 * However, the method below enables the automatic setting of the starting and end
	 * points of each scale, in such a way that the scales are positioned one
	 * after the other, from top to bottom and without overlapping. A gap 
	 * corresponding to 3 pct of the vertical axis is inserted between each scale,
	 * to prevent overlapping of scales labels.
	 */
	graph.setAutoScalePositioningEnabled(true);
	//graph.setScalesGap(.03F);

	/**
	 * Although the GraphSet objects must be manually created and added to the
	 * chart context, the Graph class keeps a reference to  a primary GraphSet
	 * object, whose scale range delimits the area where all series not added
	 * to any other secondary GraphSet objects are painted.
	 */
	setDefaultGraphSetProperties();

	// Creates the first GraphSet object. The bar series is added to this GraphSet.
	createFirstGraphSet();
	
	// Creates the second GraphSet object. The area series is added to this
	// GraphSet.
	createSecondGraphSet();
	
	// Creates the third GraphSet object. The candlestick series is added to this
	// GraphSet.
	createThirdGraphSet();

	// The final step: adds all the GraphSet objects to the chart context.
	graph.addGraphSet(gs1);
	graph.addGraphSet(gs2);
	graph.addGraphSet(gs3);

        Container ct=getContentPane();

	ct.add("Center",graph);

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
	
	setSize(600,500);

	setVisible(true);

    }

    private void createGraph() {

	// Sets labels
	String[] labels=new String[]{"label1","label2","label3","label4","label5",
				   "label6","label7","label8","label9","label10"};
	
	graph=new Graph(labels);
	graph.setTitle(new String[]{"The JetChart Library - Multiple Scales Demo"});
	graph.getLegend().setPosition(Legend.LEFT);
	graph.getToolTip().setEnabled(true);
	graph.getToolTip().setMultipleEnabled(true);
	graph.getToolTip().setMatchingBorderEnabled(true);
	graph.getToolTip().setPointerType(ToolTip.NONE);

    }
    
    private void setDefaultGraphSetProperties() {

	// Gets a reference to the primary GraphSet object. All series that were not added
	// to any secondary GraphSet are automatically added to the primary GraphSet.
	GraphSet defaultGraphSet=graph.getGraphSet(0);

	// Enables the grid of the primary GraphSet.
	defaultGraphSet.getGrid().setEnabled(true);

	// Enables the scrolling bar.
	defaultGraphSet.getScrollingBar().setEnabled(true);


	// Sets the scale color and font.
	Scale scale=graph.getGraphSet(0).getScale();
    	scale.setColor(Color.magenta);
	//scale.setFont(new Font("Arial",Font.BOLD,14));
    }


    private void createFirstGraphSet() {

	// Creates a new GraphSet object.
	gs1=new GraphSet();

	// Adds the bar series.
	gs1.addSerie(bs);

	// Enables the grid, sets its color and the scale color.
	gs1.getGrid().setEnabled(true);
	gs1.getGrid().setColor(Color.lightGray);
	gs1.getScale().setColor(Color.green.darker());

	// Enables the scrolling bar
	gs1.getScrollingBar().setEnabled(true);

    }
    
    private void createSecondGraphSet() {	

	// Creates a GraphSet.
	gs2=new GraphSet();

	// Adds the area series.
	gs2.addSerie(as);

	// Enables grid and sets its color.
	gs2.getGrid().setEnabled(true);
	gs2.getGrid().setColor(new Color(102,255,255));

	// Enables the scrolling bar
	gs2.getScrollingBar().setEnabled(true);
	
	// Sets the scale position, disables the automatic scale, sets the minimum scale value,
	// color and font.
	Scale scale=gs2.getScale();
	scale.setPosition(Scale.RIGHT);
	scale.setAutoScaleEnabled(false);
	scale.setMinValue(140);
	scale.setColor(Color.red);
	scale.setFont(new Font("Monospaced",Font.ITALIC,12));
    }

    private void createThirdGraphSet() {

	// Creates a GraphSet object.
	gs3=new GraphSet();

	// Adds the candlestick series.
	gs3.addSerie(cs);

	// Enables grid and colored bands, sets scale position to the right, 
	// disables automatic scale and sets minimum value, increment and 
	// scale color.
	gs3.getGrid().setEnabled(true);
	gs3.getGrid().setColoredBandsEnabled(true);
	gs3.getScale().setPosition(Scale.RIGHT);
	gs3.getScale().setAutoScaleEnabled(false);
	gs3.getScale().setMinValue(170);
	gs3.getScale().setIncrement(10);
	gs3.getScale().setColor(Color.blue);

	// Enables the scrolling bar
	gs3.getScrollingBar().setEnabled(true);
    }

    public static void main(String[] args) {
	new Main();
    }
}
